@@ -1,15 +1,13 @@
-import logging
 import yaml
 
-
 from os import path, chdir
 
-
+from squad_client import logging
 from squad_client.core.command import SquadClientCommand
 from squad_client.report import ReportGenerator
 
 
-logger = logging.getLogger()
+logger = logging.getLogger(__name__)
 
 
 class ReportCommand(SquadClientCommand):
