@@ -108,7 +108,7 @@ class SquadApi:
             kwargs['params'] = params
 
         url = '%s%s' % (SquadApi.url, endpoint if endpoint[0] != '/' else endpoint[1:])
-        logger.debug('%s %s' % (method, url))
+        logger.debug('%s %s (%s)' % (method, url, kwargs))
 
         if SquadApi.headers:
             kwargs['headers'] = SquadApi.headers
