@@ -67,9 +67,9 @@ class SubmitTuxbuildCommandTest(unittest.TestCase):
         builds = load_builds(os.path.join(self.buildset_dir, "build.json"))
 
         tests = [
-            "build/x86_64-gcc-8-allnoconfig",
-            "build/x86_64-gcc-8-tinyconfig",
-            "build/x86_64-gcc-8-x86_64_defconfig",
+            "build/gcc-8-allnoconfig",
+            "build/gcc-8-tinyconfig",
+            "build/gcc-8-x86_64_defconfig",
         ]
 
         self.assertEqual([create_name(build) for build in builds], tests)
@@ -269,40 +269,40 @@ class SubmitTuxbuildCommandIntegrationTest(unittest.TestCase):
         suite = project.suite('build')
         self.assertIsNotNone(suite)
 
-        test = first(self.squad.tests(name='x86_64-gcc-8-allnoconfig'))
-        self.assertEqual('build/x86_64-gcc-8-allnoconfig', test.name)
+        test = first(self.squad.tests(name='gcc-8-allnoconfig'))
+        self.assertEqual('build/gcc-8-allnoconfig', test.name)
         self.assertEqual('pass', test.status)
 
-        test = first(self.squad.tests(name='x86_64-gcc-8-tinyconfig'))
-        self.assertEqual('build/x86_64-gcc-8-tinyconfig', test.name)
+        test = first(self.squad.tests(name='gcc-8-tinyconfig'))
+        self.assertEqual('build/gcc-8-tinyconfig', test.name)
         self.assertEqual('pass', test.status)
 
-        test = first(self.squad.tests(name='x86_64-gcc-8-x86_64_defconfig'))
-        self.assertEqual('build/x86_64-gcc-8-x86_64_defconfig', test.name)
+        test = first(self.squad.tests(name='gcc-8-x86_64_defconfig'))
+        self.assertEqual('build/gcc-8-x86_64_defconfig', test.name)
         self.assertEqual('pass', test.status)
 
-        metric = first(self.squad.metrics(name='x86_64-gcc-8-allnoconfig-warnings'))
-        self.assertEqual('build/x86_64-gcc-8-allnoconfig-warnings', metric.name)
+        metric = first(self.squad.metrics(name='gcc-8-allnoconfig-warnings'))
+        self.assertEqual('build/gcc-8-allnoconfig-warnings', metric.name)
         self.assertEqual(0, metric.result)
 
-        metric = first(self.squad.metrics(name='x86_64-gcc-8-tinyconfig-warnings'))
-        self.assertEqual('build/x86_64-gcc-8-tinyconfig-warnings', metric.name)
+        metric = first(self.squad.metrics(name='gcc-8-tinyconfig-warnings'))
+        self.assertEqual('build/gcc-8-tinyconfig-warnings', metric.name)
         self.assertEqual(1, metric.result)
 
-        metric = first(self.squad.metrics(name='x86_64-gcc-8-x86_64_defconfig-warnings'))
-        self.assertEqual('build/x86_64-gcc-8-x86_64_defconfig-warnings', metric.name)
+        metric = first(self.squad.metrics(name='gcc-8-x86_64_defconfig-warnings'))
+        self.assertEqual('build/gcc-8-x86_64_defconfig-warnings', metric.name)
         self.assertEqual(0, metric.result)
 
-        metric = first(self.squad.metrics(name='x86_64-gcc-8-allnoconfig-duration'))
-        self.assertEqual('build/x86_64-gcc-8-allnoconfig-duration', metric.name)
+        metric = first(self.squad.metrics(name='gcc-8-allnoconfig-duration'))
+        self.assertEqual('build/gcc-8-allnoconfig-duration', metric.name)
         self.assertEqual(324, metric.result)
 
-        metric = first(self.squad.metrics(name='x86_64-gcc-8-tinyconfig-duration'))
-        self.assertEqual('build/x86_64-gcc-8-tinyconfig-duration', metric.name)
+        metric = first(self.squad.metrics(name='gcc-8-tinyconfig-duration'))
+        self.assertEqual('build/gcc-8-tinyconfig-duration', metric.name)
         self.assertEqual(350, metric.result)
 
-        metric = first(self.squad.metrics(name='x86_64-gcc-8-x86_64_defconfig-duration'))
-        self.assertEqual('build/x86_64-gcc-8-x86_64_defconfig-duration', metric.name)
+        metric = first(self.squad.metrics(name='gcc-8-x86_64_defconfig-duration'))
+        self.assertEqual('build/gcc-8-x86_64_defconfig-duration', metric.name)
         self.assertEqual(460, metric.result)
 
         build.delete()
